@@ -1,7 +1,11 @@
 import os
 from pathlib import Path
 
-from epythet.docs_gen.templates import table_of_contents_header, RstTitle, AutoDocs
+from epythet.docs_gen.templates import (
+    table_of_contents_header,
+    RstTitle,
+    AutoDocs,
+)
 from epythet.pack_util import read_configs, DFLT_CONFIG_FILE
 from py2store.filesys import FileCollection
 from py2store.trans import filt_iter
@@ -11,7 +15,10 @@ from types import ModuleType
 path_sep = os.path.sep
 
 
-def gen_rst_docs_and_path(module: Union[ModuleType, str], auto_options: List[AutoDocs] = (AutoDocs.members,)):
+def gen_rst_docs_and_path(
+    module: Union[ModuleType, str],
+    auto_options: List[AutoDocs] = (AutoDocs.members,),
+):
     """Generates autodocs rst and rst path relative to module file structure
         TODO: use epythet.docs_gen.templates.AutoDocs
 
@@ -25,13 +32,17 @@ def gen_rst_docs_and_path(module: Union[ModuleType, str], auto_options: List[Aut
     root_name_length = len(root_name) + 1
     module_name = module.__name__
     init_path = path_sep + '__init__'
-    for pyfile in filt_iter(FileCollection(root_name), filt=lambda x: x.endswith('.py')):
+    for pyfile in filt_iter(
+        FileCollection(root_name), filt=lambda x: x.endswith('.py')
+    ):
         with open(pyfile) as f:
             pyfile_contents = f.read()
         if len(pyfile_contents) == 0:
             continue
 
-        module_path = os.path.join(module_name, pyfile[root_name_length:-3]).replace(init_path, '')
+        module_path = os.path.join(
+            module_name, pyfile[root_name_length:-3]
+        ).replace(init_path, '')
         module_ref = module_path.replace(path_sep, '.')
         rst_path = module_path + '.rst'
 
@@ -39,12 +50,18 @@ def gen_rst_docs_and_path(module: Union[ModuleType, str], auto_options: List[Aut
             rst_doc = AutoDocs.make_automodule(module_ref, options=None)
         else:  # generate auto_docs with title and auto_options
             rst_title = RstTitle.make_title(module_ref, RstTitle.section)
-            rst_doc = rst_title + AutoDocs.make_automodule(module_ref, options=auto_options)
+            rst_doc = rst_title + AutoDocs.make_automodule(
+                module_ref, options=auto_options
+            )
         yield rst_doc, rst_path
 
 
-def make_autodocs_for_modules_files(module: Union[ModuleType, str], output_dirname='module_docs',
-                                    skip_existing=True, docsrc_dir=None):
+def make_autodocs_for_modules_files(
+    module: Union[ModuleType, str],
+    output_dirname='module_docs',
+    skip_existing=True,
+    docsrc_dir=None,
+):
     """Create sphinx autodocs for module and table of contents
 
     :param module: module or import name
@@ -72,7 +89,12 @@ def make_autodocs_for_modules_files(module: Union[ModuleType, str], output_dirna
     table_of_contents_rst_path.write_text(table_of_contents_rst_doc)
 
 
-def make_autodocs(project_dir, output_dirname='module_docs', skip_existing=True, docsrc_dir=None):
+def make_autodocs(
+    project_dir,
+    output_dirname='module_docs',
+    skip_existing=True,
+    docsrc_dir=None,
+):
     """Create sphinx autodocs and table of contents for module defined by setup.cfg
 
     :param project_dir: Path to root project directory containing setup.cfg
@@ -81,11 +103,15 @@ def make_autodocs(project_dir, output_dirname='module_docs', skip_existing=True,
     :param docsrc_dir: path to sphinx docs source file
     """
     config = read_configs(Path(project_dir) / DFLT_CONFIG_FILE)
-    make_autodocs_for_modules_files(module=config['name'], output_dirname=output_dirname,
-                                    skip_existing=skip_existing, docsrc_dir=docsrc_dir)
+    make_autodocs_for_modules_files(
+        module=config['name'],
+        output_dirname=output_dirname,
+        skip_existing=skip_existing,
+        docsrc_dir=docsrc_dir,
+    )
 
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     import argh
 
     argh.dispatch_command(make_autodocs)
